==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fIfgt.h <==
// class soot.coffi.Instruction_Ifgt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 3a6e0f16b5ae5d21 soot_coffi_Instruction__5fIfgt
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch
// @dep_class 6bcdce6545109d8e soot_coffi_Instruction__5fintbranch

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintbranch

#include "soot/coffi/Instruction__5fintbranch.h"

#ifndef _JC_soot_coffi_Instruction__5fIfgt_H_
#define _JC_soot_coffi_Instruction__5fIfgt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIfgt$sub_refs	_jc_soot_coffi_Instruction__5fIfgt$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIfgt$sub_nonrefs	_jc_soot_coffi_Instruction__5fIfgt$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIfgt$refs	_jc_soot_coffi_Instruction__5fIfgt$refs;
typedef struct _jc_soot_coffi_Instruction__5fIfgt$nonrefs	_jc_soot_coffi_Instruction__5fIfgt$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIfgt$object	_jc_soot_coffi_Instruction__5fIfgt$object;

typedef const struct _jc_soot_coffi_Instruction__5fIfgt$vmethods	_jc_soot_coffi_Instruction__5fIfgt$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIfgt$vtable	_jc_soot_coffi_Instruction__5fIfgt$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIfgt$vtype	_jc_soot_coffi_Instruction__5fIfgt$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIfgt$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIfgt$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIfgt$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIfgt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
	_jc_soot_coffi_Instruction__5fintbranch$vmethods	soot_coffi_Instruction__5fintbranch;
	_jc_soot_coffi_Instruction__5fIfgt$vmethods	soot_coffi_Instruction__5fIfgt;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIfgt$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIfgt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIfgt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIfgt$refs {
    _jc_soot_coffi_Instruction__5fIfgt$sub_refs	soot_coffi_Instruction__5fIfgt;
    _jc_soot_coffi_Instruction__5fintbranch$sub_refs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIfgt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIfgt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction__5fintbranch$sub_nonrefs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fIfgt$sub_nonrefs	soot_coffi_Instruction__5fIfgt;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIfgt$object {
	_jc_soot_coffi_Instruction__5fIfgt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIfgt$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIfgt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIfgt$vtype _jc_soot_coffi_Instruction__5fIfgt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIfgt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIfgt$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIfgt_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fIfgt.h <==
// class soot.coffi.Instruction_Ifgt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 3a6e0f16b5ae5d21 soot_coffi_Instruction__5fIfgt
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch
// @dep_class 6bcdce6545109d8e soot_coffi_Instruction__5fintbranch

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintbranch

#include "soot/coffi/Instruction__5fintbranch.h"

#ifndef _JC_soot_coffi_Instruction__5fIfgt_H_
#define _JC_soot_coffi_Instruction__5fIfgt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIfgt$sub_refs	_jc_soot_coffi_Instruction__5fIfgt$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIfgt$sub_nonrefs	_jc_soot_coffi_Instruction__5fIfgt$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIfgt$refs	_jc_soot_coffi_Instruction__5fIfgt$refs;
typedef struct _jc_soot_coffi_Instruction__5fIfgt$nonrefs	_jc_soot_coffi_Instruction__5fIfgt$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIfgt$object	_jc_soot_coffi_Instruction__5fIfgt$object;

typedef const struct _jc_soot_coffi_Instruction__5fIfgt$vmethods	_jc_soot_coffi_Instruction__5fIfgt$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIfgt$vtable	_jc_soot_coffi_Instruction__5fIfgt$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIfgt$vtype	_jc_soot_coffi_Instruction__5fIfgt$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIfgt$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIfgt$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIfgt$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIfgt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
	_jc_soot_coffi_Instruction__5fintbranch$vmethods	soot_coffi_Instruction__5fintbranch;
	_jc_soot_coffi_Instruction__5fIfgt$vmethods	soot_coffi_Instruction__5fIfgt;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIfgt$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIfgt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIfgt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIfgt$refs {
    _jc_soot_coffi_Instruction__5fIfgt$sub_refs	soot_coffi_Instruction__5fIfgt;
    _jc_soot_coffi_Instruction__5fintbranch$sub_refs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIfgt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIfgt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction__5fintbranch$sub_nonrefs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fIfgt$sub_nonrefs	soot_coffi_Instruction__5fIfgt;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIfgt$object {
	_jc_soot_coffi_Instruction__5fIfgt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIfgt$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIfgt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIfgt$vtype _jc_soot_coffi_Instruction__5fIfgt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIfgt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIfgt$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIfgt_H_ */
